summaryrefslogtreecommitdiff
path: root/ace/Service_Config.h
diff options
context:
space:
mode:
authorschmidt <douglascraigschmidt@users.noreply.github.com>1998-10-17 04:01:21 +0000
committerschmidt <douglascraigschmidt@users.noreply.github.com>1998-10-17 04:01:21 +0000
commit6f1105732cf1db9bf847cc6c0e754fc1dfb17c31 (patch)
treecaaac5252e05a699408dea67fb86ece15703e6e0 /ace/Service_Config.h
parentc251c16b030cec7bb6964b57204db02ed6606a92 (diff)
downloadATCD-6f1105732cf1db9bf847cc6c0e754fc1dfb17c31.tar.gz
*** empty log message ***
Diffstat (limited to 'ace/Service_Config.h')
-rw-r--r--ace/Service_Config.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/ace/Service_Config.h b/ace/Service_Config.h
index f0430bb60dc..6d08cfc23df 100644
--- a/ace/Service_Config.h
+++ b/ace/Service_Config.h
@@ -290,8 +290,7 @@ public:
protected:
static int process_directives (void);
// Process service configuration requests that are provided in the
// <service_config_file>. Returns the number of errors that
// occurred.
static int process_commandline_directives (void);
// Process service configuration requests that were provided on the
@@ -315,9 +314,6 @@ protected:
// <ACE_Service_Repository>.
private:
- static const ASYS_TCHAR *service_config_file_;
- // Name of service configuration file.
-
static LPCTSTR logger_key_;
// Where to write the logging output.
@@ -325,7 +321,11 @@ private:
// Singleton repository of statically linked services.
static ACE_SVC_QUEUE *svc_queue_;
- // Queue of services requested on the command-line.
+ // Queue of services specified on the command-line.
+
+ static ACE_SVC_QUEUE *svc_conf_file_queue_;
+ // Queue of svc.conf files specified on the command-line.
+ // @@ This should probably be made to handle unicode filenames...
static sig_atomic_t reconfig_occurred_;
// True if reconfiguration occurred.
@@ -290,8 +290,7 @@ public:
static int process_directives (void);
// Process service configuration requests that are provided in the
- // <service_config_file>. Returns the number of errors that
- // occurred.
+ // svc.config file(s). Returns the number of errors that occurred.
static int process_commandline_directives (void);
// Process service configuration requests that were provided on the